@@ -30,7 +30,12 @@ except ConfigParser.NoSectionError as e:
     if "DOCGENERATION" not in os.environ:
         raise
 
-from tailored.webdriver import WebDriver
+try:
+    from tailored.webdriver import WebDriver
+except ImportError as e:
+    if "DOCGENERATION" not in os.environ:
+        raise
+
 from selenium.webdriver.common.by import By
 from selenium.common.exceptions import WebDriverException
 from selenium.common.exceptions import TimeoutException
@@ -38,7 +43,7 @@ from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from saunter.testcase.base import BaseTestCase
 from saunter.SaunterWebDriver import SaunterWebDriver
-from _pytest.mark import MarkInfo
+import py.test
 
 capabilities_map = {
     "firefox": DesiredCapabilities.FIREFOX,
@@ -64,6 +69,7 @@ class SaunterTestCase(BaseTestCase):
         """
         self.verificationErrors = []
         self.cf = saunter.ConfigWrapper.ConfigWrapper().config
+        self.config = self.cf
         if self.cf.getboolean("SauceLabs", "ondemand"):
             desired_capabilities = {
                 "platform": self.cf.get("SauceLabs", "os"),
@@ -129,7 +135,7 @@ class SaunterTestCase(BaseTestCase):
             # tags
             j["tags"] = []
             for keyword in self._resultForDoCleanups.keywords:
-                if isinstance(self._resultForDoCleanups.keywords[keyword], MarkInfo):
+                if isinstance(self._resultForDoCleanups.keywords[keyword], py.test.mark.MarkInfo):
                     j["tags"].append(keyword)
 
             # update
